export

Function export 

pub fn export(path: &Path, rev: &str) -> Result<(String, usize)>
Export every local Tak record attached to rev as one bounded, versioned file suitable for an artifact upload.